@@ -62,7 +62,7 @@ def indent_lines(s: str, indent: str = DEFAULT_INDENT) -> str:
     return indent + f"\n{indent}".join(chunks)
 
 
-def imports() -> str:
+def imports(enums_module: str) -> str:
     lines = [
         "from __future__ import annotations",
         "import typing as T",
@@ -73,11 +73,17 @@ def imports() -> str:
         "from edgedb import RelativeDuration, AsyncIOClient, create_async_client",
         "from pydantic import BaseModel, Field, PrivateAttr, validator",
         f"from {PATH_TO_MODULE} import Node, Resolver, NodeException, ResolverException, UpdateOperation, Batch, Unset, ComputedPropertyException, AppendixPropertyException, is_unset, from_str, enum_from_str",
+        f"from .{enums_module} import *",
         'EdgeResolverType = T.TypeVar("EdgeResolverType", bound=Resolver)',
     ]
     return "\n".join(lines)
 
 
+def build_enum_imports() -> str:
+    lines = ["from enum import Enum"]
+    return "\n".join(lines)
+
+
 async def build_enums(client: edgedb.AsyncIOClient, include_strawberry: bool) -> str:
     scalar_types = await introspect_scalars(client)
     enum_strs: T.List[str] = []
@@ -578,9 +584,24 @@ def get_nodes_to_hydrate(db_config: DBConfig) -> T.Set[str]:
     return node_names
 
 
+async def build_enums_from_config(db_config_d: dict, include_strawberry: bool) -> str:
+    db_config = DBConfig.parse_obj(db_config_d)
+    client = edgedb.create_async_client(
+        tls_security=db_config.tls_security,
+        host=db_config.host,
+        password=db_config.password,
+        port=db_config.port,
+    )
+    enums_imports = build_enum_imports()
+    enums_str = await build_enums(client, include_strawberry=include_strawberry)
+    s = "\n".join([enums_imports, enums_str])
+    s = format_str(s, mode=FileMode())
+    return s
+
+
 async def build_from_config(
     db_config_d: dict,
-    include_strawberry: bool,
+    enums_module: str,
     hydrate: bool = False,
     dehydrate: bool = False,
 ) -> str:
@@ -591,11 +612,10 @@ async def build_from_config(
         password=db_config.password,
         port=db_config.port,
     )
-    imports_str = imports()
+    imports_str = imports(enums_module=enums_module)
     client_str = build_client(db_config)
     validator_module_imports = build_validator_module_imports(db_config)
     hydrate_imports = "" if not hydrate else build_hydrate_imports(db_config)
-    enums_str = await build_enums(client, include_strawberry=include_strawberry)
     nodes_and_resolvers_str = await build_nodes_and_resolvers(
         client,
         db_config=db_config,
@@ -609,7 +629,6 @@ async def build_from_config(
             client_str,
             validator_module_imports,
             hydrate_imports,
-            enums_str,
             nodes_and_resolvers_str,
         ]
     )
@@ -622,18 +641,24 @@ async def generate(
 ) -> None:
     validate_output_path(output_path)
     for db_name, db_config_d in json.loads(open(config_path).read()).items():
+        # first build enums folder
+        enums_s = await build_enums_from_config(
+            db_config_d=db_config_d, include_strawberry=include_strawberry
+        )
+        enums_module = f"{db_name}_enums"
+        open(output_path / f"{enums_module}.py", "w").write(enums_s)
         hydrate = db_config_d.get("hydrate", False)
         # must include strawberry types in both for circular dependency reasons
         s = await build_from_config(
             db_config_d=db_config_d,
-            include_strawberry=include_strawberry,
             dehydrate=hydrate,
+            enums_module=enums_module,
         )
         open(output_path / f"{db_name}.py", "w").write(s)
         if hydrate:
             s = await build_from_config(
                 db_config_d=db_config_d,
                 hydrate=True,
-                include_strawberry=include_strawberry,
+                enums_module=enums_module,
             )
             open(output_path / f"{db_name}_hydrated.py", "w").write(s)
